@@ -4,20 +4,19 @@
 #include <pcl/features/pfh.h>
 #include <pcl/features/pfhrgb.h>
 #include <pcl/features/shot_omp.h>
+#include <pcl/filters/extract_indices.h> // for ExtractIndices
 #include <pcl/io/pcd_io.h>
 #include <pcl/keypoints/harris_3d.h>
 #include <pcl/keypoints/sift_keypoint.h>
 #include <pcl/registration/correspondence_rejection_sample_consensus.h>
 #include <pcl/registration/icp.h>
 #include <pcl/registration/transformation_estimation_svd.h>
-#include <pcl/registration/transforms.h>
 #include <pcl/sample_consensus/method_types.h>
 #include <pcl/sample_consensus/model_types.h>
 #include <pcl/search/kdtree.h>
 #include <pcl/segmentation/extract_clusters.h>
 #include <pcl/segmentation/sac_segmentation.h>
 #include <pcl/surface/gp3.h>
-#include <pcl/surface/grid_projection.h>
 #include <pcl/surface/marching_cubes_hoppe.h>
 #include <pcl/visualization/pcl_visualizer.h>
 #include <pcl/ModelCoefficients.h>
@@ -222,7 +221,7 @@ ICCVTutorial<FeatureType>::segmentation(
   extract.setNegative(true);
 
   extract.filter(*segmented);
-  std::vector<int> indices;
+  pcl::Indices indices;
   pcl::removeNaNFromPointCloud(*segmented, *segmented, indices);
   std::cout << "OK" << std::endl;
 
@@ -247,7 +246,7 @@ ICCVTutorial<FeatureType>::segmentation(
     if (cluster_indices.size() > 1)
       std::cout << " Using largest one...";
     std::cout << std::endl;
-    typename pcl::IndicesPtr indices(new std::vector<int>);
+    typename pcl::IndicesPtr indices(new pcl::Indices);
     *indices = cluster_indices[0].indices;
     extract.setInputCloud(segmented);
     extract.setIndices(indices);
@@ -326,7 +325,7 @@ ICCVTutorial<FeatureType>::findCorrespondences(
   // Find the index of the best match for each keypoint, and store it in
   // "correspondences_out"
   const int k = 1;
-  std::vector<int> k_indices(k);
+  pcl::Indices k_indices(k);
   std::vector<float> k_squared_distances(k);
   for (int i = 0; i < static_cast<int>(source->size()); ++i) {
     descriptor_kdtree.nearestKSearch(*source, i, k, k_indices, k_squared_distances);
