@@ -157,23 +157,21 @@ public:
   saveCloud()
   {
     FPS_CALC("I/O");
-    std::stringstream ss;
-    ss << dir_name_ << "/" << file_name_ << "_"
-       << boost::posix_time::to_iso_string(
-              boost::posix_time::microsec_clock::local_time())
-       << ".pcd";
+    const std::string time = boost::posix_time::to_iso_string(
+        boost::posix_time::microsec_clock::local_time());
+    const std::string filepath = dir_name_ + '/' + file_name_ + '_' + time + ".pcd";
 
     if (format_ & 1) {
-      writer_.writeBinary<PointType>(ss.str(), *cloud_);
+      writer_.writeBinary<PointType>(filepath, *cloud_);
       // std::cerr << "Data saved in BINARY format to " << ss.str () << std::endl;
     }
 
     if (format_ & 2) {
-      writer_.writeBinaryCompressed<PointType>(ss.str(), *cloud_);
+      writer_.writeBinaryCompressed<PointType>(filepath, *cloud_);
     }
 
     if (format_ & 4) {
-      writer_.writeBinaryCompressed<PointType>(ss.str(), *cloud_);
+      writer_.writeBinaryCompressed<PointType>(filepath, *cloud_);
     }
   }
 
