@@ -37,11 +37,12 @@
 #include <pcl/console/parse.h>
 #include <pcl/io/openni_camera/openni_driver.h>
 #include <pcl/io/openni_grabber.h>
+#include <pcl/search/kdtree.h> // for KdTree
 #include <pcl/surface/mls.h>
-#include <pcl/visualization/cloud_viewer.h>
+#include <pcl/visualization/keyboard_event.h> // for KeyboardEvent
+#include <pcl/visualization/pcl_visualizer.h> // for PCLVisualizer
 #include <pcl/point_cloud.h>
 #include <pcl/point_types.h>
-#include <pcl/search/kdtree.h> // for KdTree
 
 #include <mutex>
 
