@@ -1,5 +1,4 @@
-#ifndef KISS_FTR_H
-#define KISS_FTR_H
+#pragma once
 
 #include "kiss_fft.h"
 #ifdef __cplusplus
@@ -43,4 +42,3 @@ void PCL_EXPORTS kiss_fftri(kiss_fftr_cfg cfg,const kiss_fft_cpx *freqdata,kiss_
 #ifdef __cplusplus
 }
 #endif
-#endif
