@@ -39,9 +39,10 @@
 
 #pragma once
 
-#include <pcl/common/eigen.h>
 #include <pcl/point_cloud.h>
 
+#include <Eigen/Core> // for VectorXf
+
 #include <functional>
 
 namespace pcl
