@@ -772,7 +772,7 @@ transformPlane (const Eigen::Matrix<Scalar, 4, 1> &plane_in,
 
 
 template <typename Scalar> void
-transformPlane (const pcl::ModelCoefficients::Ptr plane_in,
+transformPlane (const pcl::ModelCoefficients::ConstPtr plane_in,
                       pcl::ModelCoefficients::Ptr plane_out,
                 const Eigen::Transform<Scalar, 3, Eigen::Affine> &transformation)
 {
@@ -780,7 +780,7 @@ transformPlane (const pcl::ModelCoefficients::Ptr plane_in,
   Eigen::Matrix < Scalar, 4, 1 > v_plane_in (values.data ());
   pcl::transformPlane (v_plane_in, v_plane_in, transformation);
   plane_out->values.resize (4);
-  std::copy_n(v_plane_in.data (), 4, plane_in->values.begin ());
+  std::copy_n(v_plane_in.data (), 4, plane_out->values.begin ());
 }
 
 
