@@ -41,10 +41,8 @@
 #include <pcl/point_cloud.h>
 #include <pcl/pcl_macros.h>
 #include <pcl/point_types.h>
-#include <pcl/PCLPointCloud2.h> // for PCLPointCloud2
 #include <pcl/common/angles.h> // for deg2rad
-#include <pcl/common/vector_average.h>
-#include <typeinfo>
+namespace pcl { struct PCLPointCloud2; }
 
 namespace pcl
 {
