@@ -146,7 +146,7 @@ pcl::GaussianKernel::convolveRows (const pcl::PointCloud<float>& input,
     {
       output.width = input.width;
       output.height = input.height;
-      output.points.resize (input.height * input.width);
+      output.resize (input.height * input.width);
     }
     unaliased_input = &input;
   }
@@ -190,7 +190,7 @@ pcl::GaussianKernel::convolveCols (const pcl::PointCloud<float>& input,
     {
       output.width = input.width;
       output.height = input.height;
-      output.points.resize (input.height * input.width);
+      output.resize (input.height * input.width);
     }
     unaliased_input = &input;
   }
