@@ -37,12 +37,16 @@
  *
  */
 
+
 #ifndef PCL_FEATURES_IMPL_BRISK_2D_HPP_
 #define PCL_FEATURES_IMPL_BRISK_2D_HPP_
 
-///////////////////////////////////////////////////////////////////////////////////////////
+
+namespace pcl
+{
+
 template <typename PointInT, typename PointOutT, typename KeypointT, typename IntensityT>
-pcl::BRISK2DEstimation<PointInT, PointOutT, KeypointT, IntensityT>::BRISK2DEstimation ()
+BRISK2DEstimation<PointInT, PointOutT, KeypointT, IntensityT>::BRISK2DEstimation ()
   : rotation_invariance_enabled_ (true)
   , scale_invariance_enabled_ (true)
   , pattern_scale_ (1.0f)
@@ -81,21 +85,21 @@ pcl::BRISK2DEstimation<PointInT, PointOutT, KeypointT, IntensityT>::BRISK2DEstim
   generateKernel (r_list, n_list, 5.85f * pattern_scale_, 8.2f * pattern_scale_);
 }
 
-///////////////////////////////////////////////////////////////////////////////////////////
+
 template <typename PointInT, typename PointOutT, typename KeypointT, typename IntensityT>
-pcl::BRISK2DEstimation<PointInT, PointOutT, KeypointT, IntensityT>::~BRISK2DEstimation ()
+BRISK2DEstimation<PointInT, PointOutT, KeypointT, IntensityT>::~BRISK2DEstimation ()
 {
-   if (pattern_points_) delete [] pattern_points_;
-  if (short_pairs_) delete [] short_pairs_;
-  if (long_pairs_) delete [] long_pairs_;
-  if (scale_list_) delete [] scale_list_;
-  if (size_list_) delete [] size_list_;
+  delete [] pattern_points_;
+  delete [] short_pairs_;
+  delete [] long_pairs_;
+  delete [] scale_list_;
+  delete [] size_list_;
 }
 
-///////////////////////////////////////////////////////////////////////////////////////////
+
 template <typename PointInT, typename PointOutT, typename KeypointT, typename IntensityT> void
-pcl::BRISK2DEstimation<PointInT, PointOutT, KeypointT, IntensityT>::generateKernel (
-    std::vector<float> &radius_list, 
+BRISK2DEstimation<PointInT, PointOutT, KeypointT, IntensityT>::generateKernel (
+    std::vector<float> &radius_list,
     std::vector<int> &number_list, float d_max, float d_min,
     std::vector<int> index_change)
 {
@@ -128,20 +132,19 @@ pcl::BRISK2DEstimation<PointInT, PointOutT, KeypointT, IntensityT>::generateKern
     size_list_[scale]  = 0;
 
     // generate the pattern points look-up
-    double alpha, theta;
     for (std::size_t rot = 0; rot < n_rot_; ++rot)
     {
       // this is the rotation of the feature
-      theta = double (rot) * 2 * M_PI / double (n_rot_); 
-      for (int ring = 0; ring < rings; ++ring)
+      double theta = double (rot) * 2 * M_PI / double (n_rot_);
+      for (int ring = 0; ring < static_cast<int>(rings); ++ring)
       {
         for (int num = 0; num < number_list[ring]; ++num)
         {
           // the actual coordinates on the circle
-          alpha = double (num) * 2 * M_PI / double (number_list[ring]);
-          
+          double alpha = double (num) * 2 * M_PI / double (number_list[ring]);
+
           // feature rotation plus angle of the point
-          pattern_iterator->x = scale_list_[scale] * radius_list[ring] * static_cast<float> (std::cos (alpha + theta)); 
+          pattern_iterator->x = scale_list_[scale] * radius_list[ring] * static_cast<float> (std::cos (alpha + theta));
           pattern_iterator->y = scale_list_[scale] * radius_list[ring] * static_cast<float> (sin (alpha + theta));
           // and the gaussian kernel sigma
           if (ring == 0)
@@ -211,9 +214,9 @@ pcl::BRISK2DEstimation<PointInT, PointOutT, KeypointT, IntensityT>::generateKern
   strings_ = int (std::ceil ((float (no_short_pairs_)) / 128.0)) * 4 * 4;
 }
 
-///////////////////////////////////////////////////////////////////////////////////////////
+
 template <typename PointInT, typename PointOutT, typename KeypointT, typename IntensityT> inline int
-pcl::BRISK2DEstimation<PointInT, PointOutT, KeypointT, IntensityT>::smoothedIntensity (
+BRISK2DEstimation<PointInT, PointOutT, KeypointT, IntensityT>::smoothedIntensity (
     const std::vector<unsigned char> &image,
     int image_width, int,
     //const Stefan& integral,
@@ -244,26 +247,26 @@ pcl::BRISK2DEstimation<PointInT, PointOutT, KeypointT, IntensityT>::smoothedInte
     const int r_y   = static_cast<int> ((yf - float (y)) * 1024);
     const int r_x_1 = (1024 - r_x);
     const int r_y_1 = (1024 - r_y);
-    
-    //+const unsigned char* ptr = static_cast<const unsigned char*> (&image.points[0].r) + x + y * imagecols;
+
+    //+const unsigned char* ptr = static_cast<const unsigned char*> (&image[0].r) + x + y * imagecols;
     const unsigned char* ptr = static_cast<const unsigned char*>(&image[0]) + x + y * imagecols;
-    
+
     // just interpolate:
     ret_val = (r_x_1 * r_y_1 * int (*ptr));
-    
+
     //+ptr += sizeof (PointInT);
     ptr++;
 
     ret_val += (r_x * r_y_1 * int (*ptr));
-    
+
     //+ptr += (imagecols * sizeof (PointInT));
     ptr += imagecols;
-    
+
     ret_val += (r_x * r_y * int (*ptr));
-    
+
     //+ptr -= sizeof (PointInT);
     ptr--;
-    
+
     ret_val += (r_x_1 * r_y * int (*ptr));
     return (ret_val + 512) / 1024;
   }
@@ -307,32 +310,32 @@ pcl::BRISK2DEstimation<PointInT, PointOutT, KeypointT, IntensityT>::smoothedInte
   if (dx + dy > 2)
   {
     // now the calculation:
-    
-    //+const unsigned char* ptr = static_cast<const unsigned char*> (&image.points[0].r) + x_left + imagecols * y_top;
+
+    //+const unsigned char* ptr = static_cast<const unsigned char*> (&image[0].r) + x_left + imagecols * y_top;
     const unsigned char* ptr = static_cast<const unsigned char*>(&image[0]) + x_left + imagecols * y_top;
 
     // first the corners:
     ret_val = A * int (*ptr);
-  
+
     //+ptr += (dx + 1) * sizeof (PointInT);
     ptr += dx + 1;
-    
+
     ret_val += B * int (*ptr);
-    
+
     //+ptr += (dy * imagecols + 1) * sizeof (PointInT);
     ptr += dy * imagecols + 1;
-    
+
     ret_val += C * int (*ptr);
-    
+
     //+ptr -= (dx + 1) * sizeof (PointInT);
     ptr -= dx + 1;
-    
+
     ret_val += D * int (*ptr);
 
     // next the edges:
     //+int* ptr_integral;// = static_cast<int*> (integral.data) + x_left + integralcols * y_top + 1;
     const int* ptr_integral = static_cast<const int*> (&integral_image[0]) + x_left + integralcols * y_top + 1;
-    
+
     // find a simple path through the different surface corners
     const int tmp1 = (*ptr_integral);
     ptr_integral += dx;
@@ -369,16 +372,16 @@ pcl::BRISK2DEstimation<PointInT, PointOutT, KeypointT, IntensityT>::smoothedInte
   }
 
   // now the calculation:
-  
-  //const unsigned char* ptr = static_cast<const unsigned char*> (&image.points[0].r) + x_left + imagecols * y_top;
+
+  //const unsigned char* ptr = static_cast<const unsigned char*> (&image[0].r) + x_left + imagecols * y_top;
   const unsigned char* ptr = static_cast<const unsigned char*>(&image[0]) + x_left + imagecols * y_top;
-  
+
   // first row:
   ret_val = A * int (*ptr);
-  
+
   //+ptr += sizeof (PointInT);
   ptr++;
-  
+
   //+const unsigned char* end1 = ptr + (dx * sizeof (PointInT));
   const unsigned char* end1 = ptr + dx;
 
@@ -386,25 +389,25 @@ pcl::BRISK2DEstimation<PointInT, PointOutT, KeypointT, IntensityT>::smoothedInte
   for (; ptr < end1; ptr++)
     ret_val += r_y_1_i * int (*ptr);
   ret_val += B * int (*ptr);
-  
+
   // middle ones:
   //+ptr += (imagecols - dx - 1) * sizeof (PointInT);
   ptr += imagecols - dx - 1;
-  
+
   //+const unsigned char* end_j = ptr + (dy * imagecols) * sizeof (PointInT);
   const unsigned char* end_j = ptr + dy * imagecols;
-  
+
   //+for (; ptr < end_j; ptr += (imagecols - dx - 1) * sizeof (PointInT))
   for (; ptr < end_j; ptr += imagecols - dx - 1)
   {
     ret_val += r_x_1_i * int (*ptr);
-    
+
     //+ptr += sizeof (PointInT);
     ptr++;
-    
+
     //+const unsigned char* end2 = ptr + (dx * sizeof (PointInT));
     const unsigned char* end2 = ptr + dx;
-    
+
     //+for (; ptr < end2; ptr += sizeof (PointInT))
     for (; ptr < end2; ptr++)
       ret_val += int (*ptr) * scaling;
@@ -413,10 +416,10 @@ pcl::BRISK2DEstimation<PointInT, PointOutT, KeypointT, IntensityT>::smoothedInte
   }
   // last row:
   ret_val += D * int (*ptr);
-  
+
   //+ptr += sizeof (PointInT);
   ptr++;
-  
+
   //+const unsigned char* end3 = ptr + (dx * sizeof (PointInT));
   const unsigned char* end3 = ptr + dx;
 
@@ -430,29 +433,28 @@ pcl::BRISK2DEstimation<PointInT, PointOutT, KeypointT, IntensityT>::smoothedInte
 }
 
 
-//////////////////////////////////////////////////////////////////////////////
 template <typename PointInT, typename PointOutT, typename KeypointT, typename IntensityT> bool
-pcl::BRISK2DEstimation<PointInT, PointOutT, KeypointT, IntensityT>::RoiPredicate (
+BRISK2DEstimation<PointInT, PointOutT, KeypointT, IntensityT>::RoiPredicate (
     const float min_x, const float min_y,
     const float max_x, const float max_y, const KeypointT& pt)
 {
   return ((pt.x < min_x) || (pt.x >= max_x) || (pt.y < min_y) || (pt.y >= max_y));
 }
 
-///////////////////////////////////////////////////////////////////////////////////////////
+
 template <typename PointInT, typename PointOutT, typename KeypointT, typename IntensityT> void
-pcl::BRISK2DEstimation<PointInT, PointOutT, KeypointT, IntensityT>::compute (
+BRISK2DEstimation<PointInT, PointOutT, KeypointT, IntensityT>::compute (
     PointCloudOutT &output)
 {
   if (!input_cloud_->isOrganized ())
-  {    
+  {
     PCL_ERROR ("[pcl::%s::initCompute] %s doesn't support non organized clouds!\n", name_.c_str ());
     return;
   }
 
   // image size
-  const int width = int (input_cloud_->width);
-  const int height = int (input_cloud_->height);
+  const index_t width = static_cast<index_t>(input_cloud_->width);
+  const index_t height = static_cast<index_t>(input_cloud_->height);
 
   // destination for intensity data; will be forwarded to BRISK
   std::vector<unsigned char> image_data (width*height);
@@ -461,16 +463,16 @@ pcl::BRISK2DEstimation<PointInT, PointOutT, KeypointT, IntensityT>::compute (
     image_data[i] = static_cast<unsigned char> (intensity_ ((*input_cloud_)[i]));
 
   // Remove keypoints very close to the border
-  std::size_t ksize = keypoints_->points.size ();
+  auto ksize = keypoints_->size ();
   std::vector<int> kscales; // remember the scale per keypoint
   kscales.resize (ksize);
- 
+
   // initialize constants
   static const float lb_scalerange = std::log2 (scalerange_);
 
   typename std::vector<KeypointT, Eigen::aligned_allocator<KeypointT> >::iterator beginning = keypoints_->points.begin ();
   std::vector<int>::iterator beginningkscales = kscales.begin ();
-  
+
   static const float basic_size_06 = basic_size_ * 0.6f;
   unsigned int basicscale = 0;
 
@@ -482,7 +484,7 @@ pcl::BRISK2DEstimation<PointInT, PointOutT, KeypointT, IntensityT>::compute (
     unsigned int scale;
     if (scale_invariance_enabled_)
     {
-      scale = std::max (static_cast<int> (float (scales_) / lb_scalerange * (std::log2 (keypoints_->points[k].size / (basic_size_06))) + 0.5f), 0);
+      scale = std::max (static_cast<int> (float (scales_) / lb_scalerange * (std::log2 ((*keypoints_)[k].size / (basic_size_06))) + 0.5f), 0);
       // saturate
       if (scale >= scales_) scale = scales_ - 1;
       kscales[k] = scale;
@@ -497,7 +499,7 @@ pcl::BRISK2DEstimation<PointInT, PointOutT, KeypointT, IntensityT>::compute (
     const int border_x = width - border;
     const int border_y = height - border;
 
-    if (RoiPredicate (float (border), float (border), float (border_x), float (border_y), keypoints_->points[k]))
+    if (RoiPredicate (float (border), float (border), float (border_x), float (border_y), (*keypoints_)[k]))
     {
       //std::cerr << "remove keypoint" << std::endl;
       keypoints_->points.erase (beginning + k);
@@ -512,16 +514,16 @@ pcl::BRISK2DEstimation<PointInT, PointOutT, KeypointT, IntensityT>::compute (
     }
   }
 
-  keypoints_->width = std::uint32_t (keypoints_->size ());
+  keypoints_->width = keypoints_->size ();
   keypoints_->height = 1;
 
   // first, calculate the integral image over the whole image:
   // current integral image
   std::vector<int> integral ((width+1)*(height+1), 0);    // the integral image
 
-  for (std::size_t row_index = 1; row_index < height; ++row_index)
+  for (index_t row_index = 1; row_index < height; ++row_index)
   {
-    for (std::size_t col_index = 1; col_index < width; ++col_index)
+    for (index_t col_index = 1; col_index < width; ++col_index)
     {
       const std::size_t index = row_index*width+col_index;
       const std::size_t index2 = (row_index)*(width+1)+(col_index);
@@ -553,10 +555,10 @@ pcl::BRISK2DEstimation<PointInT, PointOutT, KeypointT, IntensityT>::compute (
   //output.height = 1;
   for (std::size_t k = 0; k < ksize; k++)
   {
-    unsigned char* ptr = &output.points[k].descriptor[0];
+    unsigned char* ptr = &output[k].descriptor[0];
 
     int theta;
-    KeypointT &kp    = keypoints_->points[k];
+    KeypointT &kp    = (*keypoints_)[k];
     const int& scale = kscales[k];
     int shifter = 0;
     int* pvalues = values;
@@ -636,12 +638,12 @@ pcl::BRISK2DEstimation<PointInT, PointOutT, KeypointT, IntensityT>::compute (
     // now iterate through all the pairings
     UINT32_ALIAS* ptr2 = reinterpret_cast<UINT32_ALIAS*> (ptr);
     const BriskShortPair* max = short_pairs_ + no_short_pairs_;
-    
+
     for (BriskShortPair* iter = short_pairs_; iter < max; ++iter)
     {
       t1 = *(values + iter->i);
       t2 = *(values + iter->j);
-      
+
       if (t1 > t2)
         *ptr2 |= ((1) << shifter);
 
@@ -657,14 +659,14 @@ pcl::BRISK2DEstimation<PointInT, PointOutT, KeypointT, IntensityT>::compute (
     }
 
     //ptr += strings_;
- 
+
     //// Account for the scale + orientation;
-    //ptr += sizeof (output.points[0].scale);
-    //ptr += sizeof (output.points[0].orientation);
+    //ptr += sizeof (output[0].scale);
+    //ptr += sizeof (output[0].orientation);
   }
 
   // we do not change the denseness
-  output.width = int (output.points.size ());
+  output.width = output.size ();
   output.height = 1;
   output.is_dense = true;
 
@@ -672,6 +674,7 @@ pcl::BRISK2DEstimation<PointInT, PointOutT, KeypointT, IntensityT>::compute (
   delete [] values;
 }
 
+} // namespace pcl
 
 #endif  //#ifndef PCL_FEATURES_IMPL_BRISK_2D_HPP_
 
