@@ -40,6 +40,7 @@
 #define PCL_FEATURES_IMPL_GASD_H_
 
 #include <pcl/features/gasd.h>
+#include <pcl/common/common.h> // for getMinMax3D
 #include <pcl/common/transforms.h>
 
 #include <vector>
@@ -51,7 +52,7 @@ pcl::GASDEstimation<PointInT, PointOutT>::compute (PointCloudOut &output)
   if (!Feature<PointInT, PointOutT>::initCompute ())
   {
     output.width = output.height = 0;
-    output.points.clear ();
+    output.clear ();
     return;
   }
 
