@@ -48,7 +48,7 @@ template <typename PointInT, typename PointOutT> void
 pcl::IntensitySpinEstimation<PointInT, PointOutT>::computeIntensitySpinImage (
       const PointCloudIn &cloud, float radius, float sigma, 
       int k,
-      const std::vector<int> &indices, 
+      const pcl::Indices &indices, 
       const std::vector<float> &squared_distances, 
       Eigen::MatrixXf &intensity_spin_image)
 {
@@ -115,7 +115,7 @@ pcl::IntensitySpinEstimation<PointInT, PointOutT>::computeFeature (PointCloudOut
     PCL_ERROR ("[pcl::%s::computeFeature] The search radius must be set before computing the feature!\n",
                getClassName ().c_str ());
     output.width = output.height = 0;
-    output.points.clear ();
+    output.clear ();
     return;
   }
 
@@ -125,7 +125,7 @@ pcl::IntensitySpinEstimation<PointInT, PointOutT>::computeFeature (PointCloudOut
     PCL_ERROR ("[pcl::%s::computeFeature] The number of intensity bins must be greater than zero!\n",
                getClassName ().c_str ());
     output.width = output.height = 0;
-    output.points.clear ();
+    output.clear ();
     return;
   }
   if (nr_distance_bins_ <= 0)
@@ -133,13 +133,13 @@ pcl::IntensitySpinEstimation<PointInT, PointOutT>::computeFeature (PointCloudOut
     PCL_ERROR ("[pcl::%s::computeFeature] The number of distance bins must be greater than zero!\n",
                getClassName ().c_str ());
     output.width = output.height = 0;
-    output.points.clear ();
+    output.clear ();
     return;
   }
 
   Eigen::MatrixXf intensity_spin_image (nr_intensity_bins_, nr_distance_bins_);
   // Allocate enough space to hold the radiusSearch results
-  std::vector<int> nn_indices (surface_->size ());
+  pcl::Indices nn_indices (surface_->size ());
   std::vector<float> nn_dist_sqr (surface_->size ());
  
   output.is_dense = true;
